%*******************************************************************************
%***  This program calculates cost to haul biomass from SSLs to biorefinery   **
%*******************************************************************************]
%***  definition of variables                                                 **
%***  nSSL = no.of SSLs                                                       **
%***  nSSL40 = no. of 40-ha SSLs                                              ** 
%***  nSSL80 = no. of 80-ha SSLs                                              ** 
%***  nSSL120 = no. of 120-ha SSLs                                            ** 
%***  nSSL240 = no. of 240-ha SSLs                                            **
%***  nl40 = number of truckloads hauled from 40- ha SSL                      **
%***  nl80 = number of truckloads hauled from 80- ha SSL                      **
%***  nl120 = number of truckloads hauled from 120- ha SSL                    **
%***  nl240 = number of truckloads hauled from 240- ha SSL                    **
%***  nlout = number load-out crews                                           **
%***  pduclo = achieved average load-out productivity (Mg/d) across all       **
%***           load-out operations                                            ** 
%***  nst = number of service trucks                                          ** 
%***  R = radius of production area (km)                                      **
%***  RWF = road winding factor                                               **
%***  yld=average yield (Mg/ha)                                               ** 
%***  mtrk = mass of truckload (Mg)                                           **
%***  bpm = biorefinery size (bale/min)                                       **
%***        (biorefinery operates 24/7, 48 wk/y)                              **
%***  balem = average bale mass (Mg)                                          **
%***  Pcap = biorefinery annual capacity (Mg)                                 **
%*******************************************************************************

bpm=0.5; balem=0.4; R=50; yld=6.5; mtrk=40*0.4; nlout=4; RWF=1.4; Rarc(1)=5;
nst=1; pduclo=84; 
nl40=16; nl80=32; nl120=49; nl240=97;
Pcap=bpm*balem*60*24*7*48; 
nSSL40=56; nSSL80=28; nSSL120=44; nSSL240=22; 
%nSSL40=112; nSSL80=56; nSSL120=87; nSSL240=44; 
%nSSL40=168; nSSL80=84; nSSL120=131; nSSL240=66; 

nSSL=nSSL40+nSSL80+nSSL120+nSSL240;

fprintf('\n Biorefinery capacity (bale/min) %6.1f',bpm)
fprintf('\n No. 40-ha SSLs %6.0f',nSSL40)
fprintf('\n No. 80-ha SSLs %6.0f',nSSL80)
fprintf('\n No. 120-ha SSLs %6.0f',nSSL120)
fprintf('\n No. 240-ha SSLs %6.0f',nSSL240)
fprintf('\n Total No. SSLs %6.0f',nSSL)
fprintf('\n No. Truckloads in 40-ha SSLs %6.1f',nl40)
fprintf('\n No. Truckloads in 80-ha SSLs %6.1f',nl80)
fprintf('\n No. Truckloads in 120-ha SSLs %6.1f',nl120)
fprintf('\n No. Truckloads in 240-ha SSLs %6.1f',nl240)
fprintf('\n No. service trucks %6.0f',nst)
fprintf('\n No. SSL load-out operations %6.0f',nlout)
fprintf('\n Average achieved productivity across all load-out operations (Mg/d)%6.1f',pduclo)
fprintf('\n Radius of production area (km) %6.0f',R)
fprintf('\n Average yield across the production area (Mg/ha) %6.1f',yld)
%fprintf('\n Average distance between SSLs(km) %6.0f', dbSSL)
fprintf('\n Road Winding factor (dec) %6.1f', RWF)
fprintf('\n Spacing of annular rings for spatial analysis (km) %6.1f', Rarc(1))


%*******************************************************************************
%***  Calculate area of annualar rings                                        **
%***   Rarc(i) =- radius of ith ring (km)                                     **
%***   Aarc(i) = area of ith annulus (km2)                                    **
%***   slhd(i) = straight line haul distance for ith annulus (km)             **
%******************************************************************************* 
                                                             
  
 for i=2:11
   Rarc(i)=Rarc(i-1)+5;
 end
 Aarc(1)=pi*Rarc(1)^2;
 for i=2:10
  Aarc(i)=pi*(Rarc(i)^2-Rarc(i-1)^2);
 end
 slhd(1)=Rarc(1)/2;
 for i=2:10
   slhd(i)=(Rarc(i-1)+Rarc(i))/2; 
 end
 
%*******************************************************************************
%***  Output spatial parameters                                               **
%*******************************************************************************
 
 fprintf('\n\n Annulus Ring No. Radius (km) Area (km2) Straight line haul distance (km)')
 for i=1:10
   fprintf('\n       %6.0f      %6.1f       %6.1f         %6.1f',i,Rarc(i),Aarc(i),slhd(i))
 end
 
%*******************************************************************************
%***  Calculate no. of SSLs of each size in each annular ring                 **
%***   nannl40(i) = no. 40-ha SSLs in ith ring                                **
%***   nannl80(i) = no. 80-ha SSLs in ith ring                                **
%***   nannl120(i) = no. 120-ha SSLs in ith ring                              **
%***   nannl240(i) = no. 240-ha SSLs in ith ring                              **
%*******************************************************************************

nannl40=[1 2 3 4 5 6 7 8 9 11]; 
nannl80=[0 1 1 2 3 3 4 4 5 5]; 
nannl120=[1 1 2 3 4 5 6 7 7 8]; 
nannl240=[0 1 1 2 2 2 3 3 4 4];

%nannl40=[1 3 6 8 10 12 15 17 19 21]; 
%nannl80=[1 2 3 4 5 6 7 8 9 11]; 
%nannl120=[0 3 4 6 8 10 11 13 15 17]; 
%nannl240=[1 1 2 3 4 5 6 7 7 8];

%nannl40=[3 5 8 12 15 18 22 25 28 32]; 
%nannl80=[0 3 4 6 8 9 11 13 14 16]; 
%nannl120=[1 4 7 9 12 14 17 20 22 25]; 
%nannl240=[2 2 3 5 6 7 8 10 11 12];

 
%*******************************************************************************
%***  Check computations                                                      **
%*******************************************************************************

n40chk=0.0;
n80chk=0.0;
n120chk=0.0;
n240chk=0.0;
for i=1:10
  n40chk=n40chk+nannl40(i);
  n80chk=n80chk+nannl80(i);
  n120chk=n120chk+nannl120(i);
  n240chk=n240chk+nannl240(i);
end

  
%*******************************************************************************
%***  Output no. of SSLs in each annualar ring                                **
%*******************************************************************************

fprintf('\n\n Annulus Ring No. No. 40-ha  No. 80-ha No. 120-ha  No. 240-ha')
 for i=1:10
   fprintf('\n       %6.0f      %6.1f       %6.1f    %6.1f     %6.1f',i,nannl40(i),nannl80(i),nannl120(i),nannl240(i))
 end 
fprintf('\n\n Total             %6.1f       %6.1f    %6.1f     %6.1f',n40chk,n80chk,n120chk,n240chk)
fprintf('\n\n Actual            %6.1f       %6.1f    %6.1f     %6.1f',nSSL40,nSSL80,nSSL120,nSSL240)
 
%*******************************************************************************
%***  Total SSLs in each ring                                                 **
%*******************************************************************************

for i=1:10
  n(i)=nannl40(i)+nannl80(i)+nannl120(i)+nannl240(i);
end

%*******************************************************************************
%*** Calculate total travel for equipment hauler to visit each SSL once       **
%***  Assumptions:                                                            **
%***   1.SSL are equally distributed across 50-km radius                      **                 **
%***   2. deltaR for annulus = 5 km                                           **
%***    Equip hauler travels to SSL 1, hauls from SSL 1 to SSL 2, returns to  **
%***      SSL 1, then returns to base                                         **                 
%*******************************************************************************     
%***   ehdist40 = distance traveled by equip. hauler to haul 40-ha SSLs(km)   **  
%***   ehdist80 = distance traveled by equip. hauler to haul 80-ha SSLs(km)   ** 
%***   ehdist120 = distance traveled by equip. hauler to haul 120-ha SSLs(km) ** 
%***   ehdist240 = distance traveled by equip. hauler to haul 240-ha SSLs(km) ** 
%***   ehbSSL(i) = average distance along arc centerline between adjacent     ** 
%***               SSLs in ith ring(km)                                       **
%*******************************************************************************

 ehdist40=0.0;
 ehdist80=0.0;
 ehdist120=0.0;
 ehdist240=0.0;
for i=1:10
  ehbSSL(i)=2*pi*slhd(i)/n(i);
  ehdist40=ehdist40+(slhd(i)+ehbSSL(i))*2*RWF*nannl40(i);
  ehdist80=ehdist80+(slhd(i)+ehbSSL(i))*2*RWF*nannl80(i);
  ehdist120=ehdist120+(slhd(i)+ehbSSL(i))*2*RWF*nannl120(i);
  ehdist240=ehdist240+(slhd(i)+ehbSSL(i))*2*RWF*nannl240(i);
  end
ehdist=ehdist40+ehdist80+ehdist120+ehdist240;
  
%*******************************************************************************
%***  Output total no. of SSLs in each annualar ring                          **
%***  Output equip haul distance between SSLs (km)                            **
%*******************************************************************************

fprintf('\n\n Annulus Ring No. Total SSLs in Ring Equip Haul Dist between SSLS (km)') 
for i=1:10
   fprintf('\n       %6.0f      %6.0f               %6.1f ',i,n(i),ehbSSL(i))
 end 

%*******************************************************************************
%***  Output equipment hauler travel distance for annual operations (km)      **
%*******************************************************************************

pehdist40=(ehdist40/ehdist)*100;
pehdist80=(ehdist80/ehdist)*100;
pehdist120=(ehdist120/ehdist)*100;
pehdist240=(ehdist240/ehdist)*100;

fprintf('\n\n Total eq-haul distance for 40-ha SSLs (km) %6.1f (pct) %6.1f', ehdist40,pehdist40) 
fprintf('\n Total eq-haul distance for 80-ha SSLs (km) %6.1f (pct) %6.1f', ehdist80,pehdist80) 
fprintf('\n Total eq-haul distance  for 120-ha SSLs (km) %6.1f (pct) %6.1f', ehdist120,pehdist120) 
fprintf('\n Total eq-haul distance  for 240-ha SSLs (km) %6.1f (pct) %6.1f', ehdist240,pehdist240)
fprintf('\n\n Total eq-haul distance (km) for all SSLs %6.1f', ehdist)

%*******************************************************************************
%***  Calculate total annual travel for service truck                         **
%***   Assumption: Each day, truck travales to a ring, visits all load-out    **
%***    operations, and then returns to base. This is done until al loads are **
%***    hauled from that ring. The computation is repeated for the next ring  **
%***    until all feedstock is hauled                                         **
%***    nd(i) = No. days to haul all feedstock from ith ring                  **
%*******************************************************************************

for i=1:10
  nd(i)=((40*nannl40(i)+80*nannl80(i)+120*nannl120(i)+240*nannl240(i))*yld)/(pduclo*nlout);
end
totstd=0.0;
for i=1:10
  std(i)=nd(i)*(slhd(i)+nlout*ehbSSL(i))*2*RWF;   
  totstd=totstd+std(i);
 end 
 
%*******************************************************************************
%***  Output total haul days  to haul all feedstock in each annular ring      **
%***  Output service truck travel for each annualar ring (km)                 **
%*******************************************************************************

fprintf('\n\n Annulus Ring No. Total haul days Total service truck travel(km)') 
for i=1:10
   fprintf('\n       %6.0f      %6.0f               %6.1f ',i,nd(i),std(i))
 end
 fprintf('\n\n Total service truck travel (km) %8.1f', totstd)
totstd=totstd/nst; 
 fprintf('\n\n service truck travel for each truck (km) %8.1f', totstd) 
 
%*******************************************************************************     
%***   trkhd40 = truck travel to haul all biomass from 40-ha SSLs(km)         ** 
%***   trkhd80 = truck travel to haul all biomass from 80-ha SSLs(km)         **   
%***   trkhd123 = truck travel to haul all biomass from 120-ha SSLs(km)       ** 
%***   trkhd243 = truck travel to haul all biomass from 240-ha SSLs(km)       **                                        
%*******************************************************************************

 trkhd40=0.0;
 trkhd80=0.0;
 trkhd120=0.0;
 trkhd240=0.0;
for i=1:10
  trkhd40=trkhd40+slhd(i)*2*RWF*nannl40(i)*nl40;
  trkhd80=trkhd80+slhd(i)*2*RWF*nannl80(i)*nl80;
  trkhd120=trkhd120+slhd(i)*2*RWF*nannl120(i)*nl120;
  trkhd240=trkhd240+slhd(i)*2*RWF*nannl240(i)*nl240;
end
trkhd=trkhd40+trkhd80+trkhd120+trkhd240;

%*******************************************************************************
%***  Output equipment hauler travel distance for annual operations (km)      **
%*******************************************************************************

fprintf('\n\n Total truck haul distance (km) for 40-ha SSLs %8.1f', trkhd40) 
fprintf('\n Total truck haul distance (km) for 80-ha SSLs %8.1f', trkhd80) 
fprintf('\n Total truck haul distance (km) for 120-ha SSLs %8.1f', trkhd120) 
fprintf('\n Total truck haul distance (km) for 240-ha SSLs %8.1f', trkhd240)
fprintf('\n\n Total truck haul distance (km) for all SSLs %8.1f', trkhd) 


%*******************************************************************************
%***  Calculate mass-distance totals                                       **
%***   mhd40 = haul distance-mass total for 40-ha SSLs                        **  
%***   mhd80 = haul distance-mass total for 80-ha SSLs                        **  
%***   mhd120 = haul distance-mass total for 120-ha SSLs                      **  
%***   mhd240 = haul distance-mass total for 240-ha SSLs                      **
%***   mhd = total haul distance-mass for all SSLs                            **  
%******************************************************************************* 

 mhd40=0.0;
 mhd80=0.0;
 mhd120=0.0;
 mhd240=0.0;
for i=1:10
  mhd40=mhd40+slhd(i)*RWF*nannl40(i)*40*yld;
  mhd80=mhd80+slhd(i)*RWF*nannl80(i)*80*yld;
  mhd120=mhd120+slhd(i)*RWF*nannl120(i)*120*yld;
  mhd240=mhd240+slhd(i)*RWF*nannl240(i)*240*yld;
end
mhd =mhd40+mhd80+mhd120+mhd240;

%*******************************************************************************
%***  Output mass- distance totals (Mg-km)                                    **
%*******************************************************************************

fprintf('\n\n Mass-distance (Mg-km) total for 40-ha SSLs %6.1f', mhd40) 
fprintf('\n Mass-distance (Mg-km) total for 80-ha SSLs %6.1f', mhd80) 
fprintf('\n Mass-distance (Mg-km) total for 120-ha SSLs %6.1f', mhd120) 
fprintf('\n Mass-distance (Mg-km) total for 240-ha SSLs %6.1f',mhd240)
fprintf('\n\n Total mass-distance (Mg-km) for all SSLs %6.1f', mhd)

%*******************************************************************************
%***  Calculate total mass hauled                                             **
%***  mh40 = total mass hauled (Mg)from 40-ha SSLs                            ** 
%***  mh80 = total mass hauled (Mg)from 80-ha SSLs                            ** 
%***  mh120 = total mass hauled (Mg) from 120-ha SSLs                         ** 
%***  mh240 = total mass hauled (Mg)from 240-ha SSLs                          ** 
%***  mh = totla mass hauled (Mg) from all SSLs                               **
%******************************************************************************* 

 mh40=0.0;
 mh80=0.0;
 mh120=0.0;
 mh240=0.0;
for i=1:10
  mh40=mh40+nannl40(i)*40*yld;
  mh80=mh80+nannl80(i)*80*yld;
  mh120=mh120+nannl120(i)*120*yld;
  mh240=mh240+nannl240(i)*240*yld;
end
mh =mh40+mh80+mh120+mh240;

%*******************************************************************************
%***  Output mass totals (Mg-km)                                              **
%*******************************************************************************

fprintf('\n\n Mass (Mg) total for 40-ha SSLs %6.1f', mh40) 
fprintf('\n Mass (Mg) total for 80-ha SSLs %6.1f', mh80) 
fprintf('\n Mass (Mg) total for 120-ha SSLs %6.1f', mh120) 
fprintf('\n Mass(Mg) total for 240-ha SSLs %6.1f',mh240)
fprintf('\n\n Total mass(Mg) for all SSLs %6.1f', mh)
fprintf('\n\n Biorefinery design capacity(Mg) %6.1f', Pcap)

%*******************************************************************************
%***  Calculate mass-distance parameter for production area                   **
%***    (across all SSLs)                                                     **
%*******************************************************************************

paramd=mhd/mh;
fprintf('\n\n Mass-distance parameter(km) across all SSLs %6.1f', paramd)

%*******************************************************************************
%***  Calculate average haul distance for a truckload (km)                    **
%*******************************************************************************

ntrkl=mh/mtrk;
avghd=(trkhd/ntrkl)/2;
fprintf('\n\n Total number truckloads  %6.1f',ntrkl)
fprintf('\n Average haul distance for a truckload (km)  %6.1f',avghd)

%*******************************************************************************
%***  Calculate mass distance parmeter for each ring                          **
%*******************************************************************************

for i=1:10
  mring=(narc40(i)*40+narc80(i)*80+narc120(i)*120+narc240(i)*240)*yld;
  mdring=mring*slhd(i)*RWF;
mdpara(i)=mdring/mring;
end
fprintf('\n\n Annulus Ring No. Mass-diatance (km)')
 for i=1:10
   fprintf('\n       %6.0f      %6.1f',i,mdpara(i))
 end 
 